@@ -33,9 +33,10 @@
 
 int main(int argc, char **argv)
 {
-    KAboutData aboutData("ktp-call-ui", 0, ki18n("KDE Telepathy Call Ui"), "0.4.1",
+    KAboutData aboutData("ktp-call-ui", 0, ki18n("KDE Telepathy Call Ui"), "0.5",
                           ki18n("VoIP client for KDE"), KAboutData::License_GPL,
-                          ki18n("(C) 2009, George Kiagiadakis"));
+                          ki18n("(C) 2009-2012, George Kiagiadakis\n"
+                                "(C) 2010-2011, Collabora Ltd."));
     aboutData.setProgramIconName("internet-telephony");
     aboutData.addAuthor(ki18nc("@info:credit", "George Kiagiadakis"), KLocalizedString(),
                          "kiagiadakis.george@gmail.com");
@@ -63,6 +64,7 @@ int main(int argc, char **argv)
         Tp::Features() << Tp::CallChannel::FeatureContents
                        << Tp::CallChannel::FeatureCallState
                        << Tp::CallChannel::FeatureCallMembers
+                       << Tp::CallChannel::FeatureLocalHoldState
     );
 
     Tp::ContactFactoryPtr contactFactory = Tp::ContactFactory::create(
